=======
CHANGES
=======

0.9.3
-----
- Update closurebuilder and the closure compiler.

0.9.2
-----

- Add filename to the Compile recipe options directory. So it can be referenced.

0.9.1
-----

- Add missing files into the distribution.

0.9
---

- Initial release.
